const Mesa = require('vendor/Mesa.js');
const ShopifyGraphql = require('vendor/ShopifyGraphql.js');
const Shopify= require('vendor/Shopify.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {
  script = (payload, context) => {
    let vars = context.steps;

    let cursor = null;
    try { 
      cursor = Mesa.storage.get('cursor');
    } catch (error) {
      // Do nothing brosef - why - bc it's null
    }
    if (! cursor) {
      cursor = null;
    }

    let query = `
      query getFiles($max: Int!, $after:String) {
        files(first: $max, query: "media_type:image", after:$after, sortKey:UPDATED_AT) {
          nodes {
            id      
            alt
            ... on MediaImage {
              image {
                url
              }
            }
          }
          pageInfo {
            endCursor
            hasNextPage
          }
        }
      }
    `;

    let label = "Cursor: " + cursor;

    const r = ShopifyGraphql.send(query, {
      "max": 10,
      "after": cursor,
    });

    if (r.data.files.nodes.length) {
      label += " - first file: " + r.data.files.nodes[0].image.url;
    }

    Mesa.trigger.setTaskExternalData({
      "label": label
    });

    let nextPaload = {
      "files": r.data.files.nodes,
      "pageInfo": r.data.files.pageInfo,
    };

    if (r.data.files.pageInfo.endCursor) {
      Mesa.storage.set('cursor', r.data.files.pageInfo.endCursor);
    }
    
    Mesa.output.next(nextPaload);
  }
}
